==> arrow-docs-0.7.3-sources.jar: arrow/optics/Employee$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Employee`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Employee`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Company`>> inline get()= arrow.optics.Iso(
  get = { employee: `arrow`.`optics`.`Employee` -> arrow.core.Tuple2(employee.`name`, employee.`company`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Company`> -> `arrow`.`optics`.`Employee`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Employee`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Employee`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { employee: `arrow`.`optics`.`Employee` -> employee.`name` },
  set = { value: `kotlin`.`String` ->
    { employee: `arrow`.`optics`.`Employee` ->
      employee.copy(`name` = value)
    }
  }
)

inline val `arrow`.`optics`.`Employee`.Companion.company: arrow.optics.Lens<`arrow`.`optics`.`Employee`, `arrow`.`optics`.`Company`> inline get()= arrow.optics.Lens(
  get = { employee: `arrow`.`optics`.`Employee` -> employee.`company` },
  set = { value: `arrow`.`optics`.`Company` ->
    { employee: `arrow`.`optics`.`Employee` ->
      employee.copy(`company` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Lens<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Lens<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Optional<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Optional<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Getter<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Setter<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Traversal<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Fold<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company

==> arrow-docs-0.10.4-sources.jar: arrow/optics/Employee$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Employee`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Employee`, arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Company`>> inline get()= arrow.optics.Iso(
  get = { employee: `arrow`.`optics`.`Employee` -> arrow.core.Tuple2(employee.`name`, employee.`company`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`String`, `arrow`.`optics`.`Company`> -> `arrow`.`optics`.`Employee`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Employee`.Companion.name: arrow.optics.Lens<`arrow`.`optics`.`Employee`, `kotlin`.`String`> inline get()= arrow.optics.Lens(
  get = { employee: `arrow`.`optics`.`Employee` -> employee.`name` },
  set = { employee: `arrow`.`optics`.`Employee`, value: `kotlin`.`String` -> employee.copy(`name` = value) }
)

inline val `arrow`.`optics`.`Employee`.Companion.company: arrow.optics.Lens<`arrow`.`optics`.`Employee`, `arrow`.`optics`.`Company`> inline get()= arrow.optics.Lens(
  get = { employee: `arrow`.`optics`.`Employee` -> employee.`company` },
  set = { employee: `arrow`.`optics`.`Employee`, value: `arrow`.`optics`.`Company` -> employee.copy(`company` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Lens<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Optional<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Getter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Setter<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Traversal<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Employee`>.name: arrow.optics.Fold<S, `kotlin`.`String`> inline get() = this + `arrow`.`optics`.`Employee`.name

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Lens<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Lens<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Optional<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Optional<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Getter<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Setter<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Traversal<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Employee`>.company: arrow.optics.Fold<S, `arrow`.`optics`.`Company`> inline get() = this + `arrow`.`optics`.`Employee`.company
